% This is the file essderc.cls for ESSDERC conference papers.
%
% created by Werner Lemberg <wl@gnu.org>
%
% Version 0.7 (10-Apr-1999)
%
% history:
%
% 0.1: initial version
%
% 0.2: `pdf' option added
%
% 0.3: new email address
%
% 0.5: added `wideauthors' class option
%      no trailing dot after section and subsection number in
%        references
%
% 0.6: code with and without `wideauthors' was erroneously exchanged.
%
%
% This file is heavily based on ltugboat.cls, written by Robin
% Fairbairns.
%
% The following additional style files are needed:
%
%   times.sty      for PS Times fonts (part of the PSNFSS package).
%   fontenc.sty    for T1 encoding (part of LaTeX 2e).
%   float.sty      for better float support.
%   url.sty        for internet addresses.

\def\fileversion{0.7}
\def\filedate{1999/04/10}

\edef\class@name{essderc}

\NeedsTeXFormat{LaTeX2e}[1996/12/01]
\ProvidesClass{\class@name}[\filedate\space\fileversion]


% we suppress conversion of newlines into spaces

\endlinechar \m@ne


% class specific warning and error messages

\def\ESSInfo{\ClassInfo{\class@name}}
\def\ESSError{\ClassError{\class@name}}
\def\ESSWarning{\ClassWarning{\class@name}}


%%%%%%%%%%%
% options %
%%%%%%%%%%%

% we suppress almost all options to have a consistent layout.

\DeclareOption{11pt}{
  \ESSWarning{The \class@name\space class only supports 10pt fonts:
    \MessageBreak option `\CurrentOption' ignored}}
\DeclareOption{12pt}{\csname ds@11pt\endcsname}

\DeclareOption{oneside}{Option \CurrentOption\space ignored}
\DeclareOption{twoside}{\ds@oneside}

\DeclareOption{onecolumn}{\ds@oneside}
\DeclareOption{twocolumn}{\ds@oneside}

\DeclareOption{a4paper}{\ds@oneside}
\DeclareOption{a5paper}{\ds@oneside}
\DeclareOption{b5paper}{\ds@oneside}
\DeclareOption{letterpaper}{\ds@oneside}
\DeclareOption{legalpaper}{\ds@oneside}
\DeclareOption{executivepaper}{\ds@oneside}
\DeclareOption{landscape}{\ds@oneside}

\DeclareOption{titlepage}{\ds@oneside}
\DeclareOption{notitlepage}{\ds@oneside}

\PassOptionsToPackage{T1}{fontenc}
\DeclareOption{T1}{\PassOptionsToPackage{\CurrentOption}{fontenc}}
\DeclareOption{OT1}{\PassOptionsToPackage{\CurrentOption}{fontenc}}

% whether to process the document with pdflatex

\DeclareOption{pdf}{
  \ifx\pdfoutput\@undefined
    \ESSWarning{pdflatex isn't used to process this document:
      \MessageBreak option `pdf' ignored.}
  \else
    \pdfoutput 1
    \pdfcompresslevel 9
    \pdfpagewidth 210mm
    \pdfpageheight 297mm
  \fi}

% whether to use full-width author fields

\newif\ifwide@authors@
\wide@authors@false

\DeclareOption{wideauthors}{
  \wide@authors@true}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\ProcessOptions

\LoadClass[a4paper, 10pt, oneside, twocolumn]{article}


% all these files can be found on CTAN.

\RequirePackage{times}
\RequirePackage{fontenc}
\RequirePackage{float}
\RequirePackage{url}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% general typesetting rules %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newlinechar `\^^J
\normallineskiplimit \p@


% we don't allow single lines ending or starting a column

\clubpenalty 10000
\widowpenalty 10000

\textheight 24.3cm
\textwidth 17cm

\topmargin 0.16cm
\oddsidemargin -0.54cm

\ifwide@authors@
  \def\author@width{14.5cm}
\else
  \def\author@width{7cm}
\fi


% no headers or footers in this style.

\headheight \z@
\headsep \z@

\footskip \z@

\columnwidth 8.1cm
\columnsep 0.8cm

\marginparwidth \z@
\marginparsep \z@


% all paragraphs are indented 1 pica, and there is (almost) no space
% between paragraphs.

\parindent 1pc
\parskip \z@ \@plus \p@
\partopsep \z@

\topsep 3\p@ \@plus \p@
\parsep \topsep
\itemsep \topsep

\let\@afterindentfalse \@afterindenttrue
\@afterindenttrue

\tolerance 1000
\emergencystretch 1em


% no page numbers

\let\ps@plain \ps@empty        % to suppress number on first page
                               % after \maketitle
\pagestyle{empty}

\edef\allowhyphens{
  \noexpand\hyphenpenalty\the\hyphenpenalty\relax
  \noexpand\exhyphenpenalty\the\exhyphenpenalty\relax}
\def\nohyphens{
  \hyphenpenalty\@M
  \exhyphenpenalty\@M}


%%%%%%%%%%%%%%
% font stuff %
%%%%%%%%%%%%%%

% for typesetting acronyms

\DeclareRobustCommand\SMC{
  \ifx\@currsize\normalsize\small\else
    \ifx\@currsize\small\footnotesize\else
      \ifx\@currsize\footnotesize\scriptsize\else
        \ifx\@currsize\large\normalsize\else
          \ifx\@currsize\Large\large\else
            \ifx\@currsize\LARGE\Large\else
              \ifx\@currsize\scriptsize\tiny\else
                \ifx\@currsize\tiny\tiny\else
                  \ifx\@currsize\huge\LARGE\else
                    \ifx\@currsize\Huge\huge\else
                      \small\SMC@unknown@warning
  \fi\fi\fi\fi\fi\fi\fi\fi\fi\fi}

\newcommand\SMC@unknown@warning{
  \ESSWarning{
    \string\SMC: unrecognized text font size command --
    using \string\small}}
\newcommand\textSMC[1]{{\SMC #1}}


% this is the very command the user should use

\newcommand\acro[1]{\textSMC{#1}\@}


%%%%%%%%%%%%%%%%
% authors etc. %
%%%%%%%%%%%%%%%%

% we allow multiple usage of \author, \address, \netaddress, and
% \personalURL; up to four such groups can be processed.

\newcount\authornumber
\authornumber \z@

\def\theauthor#1{\csname theauthor#1\endcsname}
\def\theaddress#1{\csname theaddress#1\endcsname}
\def\thenetaddress#1{\csname thenetaddress#1\endcsname}
\def\thePersonalURL#1{\csname thePersonalURL#1\endcsname}


% we provide some default definitions to enable warning messages in
% case they are missing.

\def\author#1{
  \global\advance\authornumber \@ne
  \expandafter\def\csname theauthor\number\authornumber\endcsname{
    \ignorespaces #1\unskip}
  \expandafter\def\csname theaddress\number\authornumber\endcsname{
    \ESSWarning{Address for #1\space missing}}
  \expandafter\def\csname thenetaddress\number\authornumber\endcsname{
    \ESSWarning{Net address for #1\space missing}}
  \expandafter\let\csname thePersonalURL\number\authornumber\endcsname
    \relax}

\def\address#1{
  \expandafter\def\csname theaddress\number\authornumber\endcsname{
    \ignorespaces\textit{#1}\unskip}}

\def\netaddress#1{
  \expandafter\def\csname thenetaddress\number\authornumber\endcsname{
    \url{#1}}}

\def\personalURL#1{
  \expandafter\def\csname thePersonalURL\number\authornumber\endcsname{
    \textrm{\acro{URL}: }
    \url{#1}}}

\def\thanks#1{
  \ESSWarning{\string\thanks\space not supported.\MessageBreak
    Use \string\address, \string\netaddress,
    and \string\personalURL\space instead}}


% here are the routines to typeset the author name together with
% its associated data.

\def\@oneauthor#1{
  \begin{center}
    \begin{minipage}{\author@width}
      \begin{center}
        \parindent \z@
        \def\\{\endgraf}
        \large
        \theauthor{#1}\\
        \theaddress{#1}\\
        {\allowhyphens
         \thenetaddress{#1}\\
         \thePersonalURL{#1}}
      \end{center}
    \end{minipage}
  \end{center}}

\def\@twoauthors#1#2{
  \begin{center}
    \begin{minipage}{\author@width}
      \begin{center}
        \parindent \z@
        \def\\{\endgraf}
        \large
        \theauthor{#1}\\
        \theaddress{#1}\\
        {\allowhyphens
         \thenetaddress{#1}\\
         \thePersonalURL{#1}}
      \end{center}
    \end{minipage}
    \hspace{0.5cm}
    \begin{minipage}{\author@width}
      \begin{center}
        \parindent \z@
        \def\\{\endgraf}
        \large
        \theauthor{#2}\\
        \theaddress{#2}\\
        {\allowhyphens
         \thenetaddress{#2}\\
         \thePersonalURL{#2}}
      \end{center}
    \end{minipage}
  \end{center}}

\ifwide@authors@
  \def\@authordata{
    {\ifcase\authornumber
       \ESSWarning{No author(s) given}
     \or
       \@oneauthor{1}
     \or
       \@oneauthor{1}
       \vskip 0.5cm
       \@oneauthor{2}
     \else
       \ESSWarning{Only up to two authors allowed if `wideauthors' is selected}
       \@oneauthor{1}
       \vskip 0.5cm
       \@oneauthor{2}
     \fi}}
\else
  \def\@authordata{
    {\ifcase\authornumber
       \ESSWarning{No author(s) given}
     \or
       \@oneauthor{1}
     \or
       \@twoauthors{1}{2}
     \or
       \@twoauthors{1}{2}
       \vskip 0.5cm
       \@oneauthor{3}
     \or
       \@twoauthors{1}{2}
       \vskip 0.5cm
       \@twoauthors{3}{4}
     \else
       \ESSWarning{Only up to four authors allowed}
       \@twoauthors{1}{2}
       \vskip 0.5cm
       \@twoauthors{3}{4}
     \fi}}
\fi

\def\@maketitle{
  \null
  \vskip 0.8cm
  \begin{center}
    \nohyphens
    \textbf{\Large\@title}
  \end{center}
  \vskip 0.8cm
  \@authordata
  \vskip 0.8cm}


%%%%%%%%%%%%%%%%%%%%%%%
% sectioning commands %
%%%%%%%%%%%%%%%%%%%%%%%

\setcounter{secnumdepth}{2}


% we want a dot after section and subsection number, but not in
% references

\renewcommand\@seccntformat[1]{\csname the#1\endcsname.\quad}

% starred section commands are suppressed; for the abstract you should
% use the abstract environment

\def\@firstofsix#1#2#3#4#5#6{#1}

\def\ESS@startsection#1{
  \@ifstar
    {\ESSWarning{*-form of \expandafter\string\csname\@firstofsix#1
       \endcsname\space inappropriate}
     \@startsection#1}
    {\@startsection#1}}

\def\section{
  \ESS@startsection{{section}{1}{0pt}{12pt}{9pt}{\large\bfseries
                                                 \rightskip 0pt plus 1fil}}}
\def\subsection{
  \ESS@startsection{{subsection}{2}{0pt}{9pt}{3pt}
    {\fontsize{10.95}{13.6pt}\selectfont\bfseries
     \rightskip 0pt plus 1fil}}}


% \subsubsection simply prints its argument in boldface, starting a
% new paragraph

\def\subsubsection{
  \ESS@startsection{{subsubsection}{3}{1pc}{0pt}
    {-\fontdimen2\font plus -\fontdimen3\font minus -\fontdimen4\font}
    {\normalfont\normalsize\bfseries}}}

\def\ESS@nosection#1#2{
  \ESSWarning{\string#1 not supported, \string#2\space used instead}
  #2}


% the other section commands are casted to \section resp. \subsubsection

\def\part{\ESS@nosection\part\section}
\def\chapter{\ESS@nosection\chapter\section}
\def\paragraph{\ESS@nosection\paragraph\subsubsection}
\def\subparagraph{\ESS@nosection\subparagraph\subsubsection}


%%%%%%%%%%%%%%%%
% environments %
%%%%%%%%%%%%%%%%

\def\ESS@safe@startsection#1{\@startsection#1}


% the abstract should be typeset in italics; we issue an warning if
% the abstract length exceeds (approx.) 20 lines

\newdimen\abstract@length

\renewenvironment{abstract}
  {\let\ESS@startsection\ESS@safe@startsection
   \section*{\abstractname}
   \itshape
   \abstract@length \pagetotal}
  {\advance \abstract@length -\pagetotal
   \abstract@length -\abstract@length
   \advance \abstract@length \baselineskip   % the first line
   \ifdim \abstract@length > 260pt
     \ESSWarning{abstract longer than 20 lines}
   \fi}


% we don't emit a `Reference' section title since we print the
% bibliography in 9pt

\renewenvironment{thebibliography}[1]
  {\let\ESS@startsection\ESS@safe@startsection
   \vskip 16pt
   \small
   \list{\@biblabel{\@arabic\c@enumiv}}
        {\settowidth\labelwidth{\@biblabel{#1}}
         \leftmargin\labelwidth
         \advance\leftmargin \labelsep
         \@openbib@code
         \usecounter{enumiv}
         \let\p@enumiv\@empty
         \renewcommand\theenumiv{\@arabic\c@enumiv}}
   \sloppy
   \clubpenalty 10000
   \@clubpenalty \clubpenalty
   \widowpenalty 10000
   \sfcode`\.\@m}
  {\def\@noitemerr{
     \@latex@warning{Empty `thebibliography' environment}}
   \endlist}


% centered figure and table environments

\newenvironment{essfigure}[1][]
  {\begin{figure}[#1]
   \begin{center}}
  {\end{center}
   \end{figure}}

\newenvironment{esstable}[1][]
  {\begin{table}[#1]
   \begin{center}}
  {\end{center}
   \end{table}}

\newenvironment{essfigure*}[1][]
  {\begin{figure*}[#1]
   \begin{center}}
  {\end{center}
   \end{figure*}}

\newenvironment{esstable*}[1][]
  {\begin{table*}[#1]
   \begin{center}}
  {\end{center}
   \end{table*}}


%%%%%%%%%%%%%%%%%%%%
% cross references %
%%%%%%%%%%%%%%%%%%%%

\def\pageref#1{
  \ESSWarning{\string\pageref\space not allowed.
    Use \string\ref\space instead.}}


%%%%%%%%%%
% floats %
%%%%%%%%%%

% using float.sty makes life easier -- here we (re)define `above' and
% `plain' caption styles

\def\floatc@above#1#2{
  \setbox\@tempboxa\hbox{\@fs@cfont #1. #2}
  \ifdim\wd\@tempboxa > \hsize
    {\@fs@cfont #1. #2}\par
  \else
    \hbox to \hsize{\hfil\box\@tempboxa\hfil}
  \fi}

\let\floatc@plain \floatc@above

\def\fs@above{
  \def\@fs@cfont{\sffamily}
  \let\@fs@capt \floatc@above
  \def\@fs@pre{}
  \def\@fs@post{}
  \def\@fs@mid{\vspace{10pt}\relax}
  \let\@fs@iftopcapt\iftrue}

\def\fs@plain{
  \def\@fs@cfont{\sffamily}
  \let\@fs@capt \floatc@above
  \def\@fs@pre{}
  \def\@fs@post{}
  \def\@fs@mid{\vspace{10pt}\relax}
  \let\@fs@iftopcapt\iffalse}

\floatstyle{above}
\restylefloat{table}
\floatstyle{plain}
\restylefloat{figure}


%%%%%%%%
% misc %
%%%%%%%%

% we want to avoid the ugly Adobe courier font

\renewcommand\ttdefault{cmtt}
\ESSInfo{Courier family replaced with CM Typewriter}

% Helvetica doesn't fit with Times

\renewcommand\sfdefault{cmss}
\ESSInfo{Helvetica family replaced with CM Sans Serif}

\urlstyle{rm}


% we issue a warning if the article is longer than four pages

\AtEndDocument{
  \ifnum \c@page > 4\relax
    \ESSWarning{article longer than 4 pages}
  \fi}


\endlinechar `\^^M

\endinput
